name = "WSME"
version = "0.2.0"

description = "Web Services Made Easy"

author = "Christophe de Vienne"
email = "python-wsme@googlegroups.com"

url = "http://bitbucket.org/cdevienne/wsme"

license = "MIT"
